@@ -9,11 +9,16 @@ import importlib
 import textwrap
 import signal
 import json
+from pygments import highlight
+from pygments.style import Style
+from pygments.token import (Name, Number, String, Keyword)
+from pygments.lexers import JsonLexer
+from pygments.formatters import Terminal256Formatter
 import jc.utils
 
 
 class info():
-    version = '1.8.1'
+    version = '1.10.0'
     description = 'jc cli output JSON conversion tool'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -22,6 +27,8 @@ class info():
 __version__ = info.version
 
 parsers = [
+    'airport',
+    'airport-s',
     'arp',
     'blkid',
     'crontab',
@@ -31,6 +38,7 @@ parsers = [
     'dig',
     'du',
     'env',
+    'file',
     'free',
     'fstab',
     'group',
@@ -49,6 +57,7 @@ parsers = [
     'lsof',
     'mount',
     'netstat',
+    'ntpq',
     'passwd',
     'pip-list',
     'pip-show',
@@ -61,6 +70,7 @@ parsers = [
     'systemctl-lj',
     'systemctl-ls',
     'systemctl-luf',
+    'timedatectl',
     'uname',
     'uptime',
     'w',
@@ -70,6 +80,28 @@ parsers = [
 ]
 
 
+class JcStyle(Style):
+    BLUE = '#2c5dcd'
+    GREY = '#4d4d4d'
+    PURPLE = '#5918bb'
+    GREEN = '#00cc00'
+
+    styles = {
+        Name.Tag: 'bold {}'.format(BLUE),    # key names
+        Keyword: GREY,                       # true, false, null
+        Number: PURPLE,                      # int, float
+        String: GREEN                        # string
+    }
+
+
+def piped_output():
+    """returns False if stdout is a TTY. True if output is being piped to another program"""
+    if sys.stdout.isatty():
+        return False
+    else:
+        return True
+
+
 def ctrlc(signum, frame):
     """exit with error on SIGINT"""
     sys.exit(1)
@@ -162,6 +194,7 @@ def helptext(message):
     Options:
             -a               about jc
             -d               debug - show trace messages
+            -m               monochrome output
             -p               pretty print output
             -q               quiet - suppress warnings
             -r               raw JSON output
@@ -176,11 +209,17 @@ def helptext(message):
     print(textwrap.dedent(helptext_string), file=sys.stderr)
 
 
-def json_out(data, pretty=False):
-    if pretty:
-        print(json.dumps(data, indent=2))
+def json_out(data, pretty=False, mono=False, piped_out=False):
+    if not mono and not piped_out:
+        if pretty:
+            print(highlight(json.dumps(data, indent=2), JsonLexer(), Terminal256Formatter(style=JcStyle))[0:-1])
+        else:
+            print(highlight(json.dumps(data), JsonLexer(), Terminal256Formatter(style=JcStyle))[0:-1])
     else:
-        print(json.dumps(data))
+        if pretty:
+            print(json.dumps(data, indent=2))
+        else:
+            print(json.dumps(data))
 
 
 def generate_magic_command(args):
@@ -194,20 +233,18 @@ def generate_magic_command(args):
         return False, None
 
     # correctly parse escape characters and spaces with shlex
-    args_given = " ".join(map(shlex.quote, args[1:])).split()
+    args_given = ' '.join(map(shlex.quote, args[1:])).split()
     options = []
 
     # find the options
-    popped = 0
-    for i, arg in enumerate(args_given):
+    for arg in list(args_given):
         # parser found - use standard syntax
         if arg.startswith('--'):
             return False, None
 
         # option found - populate option list
         elif arg.startswith('-'):
-            options.append(args_given.pop(i - popped)[1:])
-            popped += 1
+            options.extend(args_given.pop(0)[1:])
 
         # command found if iterator didn't already stop - stop iterating
         else:
@@ -268,12 +305,13 @@ def main():
             options.extend(opt[1:])
 
     debug = 'd' in options
+    mono = 'm' in options
     pretty = 'p' in options
     quiet = 'q' in options
     raw = 'r' in options
 
     if 'a' in options:
-        json_out(about_jc(), pretty=pretty)
+        json_out(about_jc(), pretty=pretty, mono=mono, piped_out=piped_output())
         exit()
 
     if sys.stdin.isatty():
@@ -314,7 +352,7 @@ def main():
         helptext('missing or incorrect arguments')
         sys.exit(1)
 
-    json_out(result, pretty=pretty)
+    json_out(result, pretty=pretty, mono=mono, piped_out=piped_output())
 
 
 if __name__ == '__main__':
